@@ -5,20 +5,18 @@
 >4D: 超立方体区域填充超球
 """
 
-# 第三方库
-import os
 import json
+import os
+
 import numpy as np
 from scipy.spatial.distance import cdist
 
-
-# 本地文件
 try:
-    from psic.calc_fraction import calc_area_fraction, calc_volume_fraction
-    from psic.plot_model import plot_circle, plot_sphere, plot_distribution
-except:
     from calc_fraction import calc_area_fraction, calc_volume_fraction
-    from plot_model import plot_circle, plot_sphere, plot_distribution
+    from plot_model import plot_circle, plot_distribution, plot_sphere
+except ImportError:
+    from psic.calc_fraction import calc_area_fraction, calc_volume_fraction
+    from psic.plot_model import plot_circle, plot_distribution, plot_sphere
 
 
 def rayleigh_set(scale, size):
@@ -47,7 +45,7 @@ def crash_time(center_1, center_2, velocity_1, velocity_2, r_1, r_2, dt):
 
     Returns
     -------
-    tc : 
+    tc : float
         两圆/球体发生碰撞的时间
     """
     a = np.sum((velocity_2-velocity_1)**2)
@@ -201,7 +199,7 @@ def create_centers(ncircle, size):
 
     """
     centers = np.random.rand(ncircle, len(size))
-    for i in range(len(size)):
+    for i, _ in enumerate(size):
         centers[:, i] = centers[:, i]*(size[i][1]-size[i][0])+size[i][0]
     return centers.astype('float32')
 
@@ -253,11 +251,11 @@ def update_radius_sets(radius_sets, radiuses):
     return radius_sets
 
 
-def packing_hyperspheres_in_hypercube(ncircle, radius_sets, size, gap, num_add, max_iter, dt0, dt_interval, status):
+def packing_spheres_in_cube(ncircle, radius_sets, size, gap, num_add, max_iter, dt0, dt_interval, status):
     """
     向区域内填充圆/球
     
-    packing_hyperspheres_in_hypercube(ncircle, radius_sets, size, gap, num_add, max_iter, dt0, dt_interval, status)
+    packing_spheres_in_cube(ncircle, radius_sets, size, gap, num_add, max_iter, dt0, dt_interval, status)
 
     Parameters
     ----------
@@ -372,47 +370,36 @@ def packing_hyperspheres_in_hypercube(ncircle, radius_sets, size, gap, num_add,
 
         if count >= max_iter:
             print('The number of iterations is out of range.')
-
+        
         try:
             if i % int(num_add/10) == 0:
                 if len(size) == 2:
                     fraction = calc_area_fraction(centers_1, radiuses_1-gap, size)
                     print(i, n, fraction)
-                    try:
-                        status['log'] += '%s, %s, %s\n' % (i, n, fraction)
-                    except:
-                        pass
+                    status['log'] += '%s, %s, %s\n' % (i, n, fraction)
 
                 if len(size) == 3:
                     fraction = calc_volume_fraction(centers_1, radiuses_1-gap, size)
-                    print(i, n, fraction)
-                    try:
-                        status['log'] += '%s, %s, %s\n' % (i, n, fraction)
-                    except:
-                        pass
-        except:
-            pass
+                    status['log'] += '%s, %s, %s\n' % (i, n, fraction)
+
+        except ZeroDivisionError:
+            print(ZeroDivisionError)
 
         if len(radius_sets_0) <= n+ncircle:
             break
         
-        try:
-            status['progress'] = int(i/num_add*100)
-        except:
-            pass
+        status['progress'] = int(i/num_add*100)
 
     return centers_1, radiuses_1
 
 
-def create_model(*args):
+def create_model(ncircle, size, gap, num_add, max_iter, dt0, dt_interval, rayleigh_para, num_ball, rad_min, rad_max, model_path, status):
     """
     根据参数列表生成填充模型
     
-    create_model(*args)
+    create_model(ncircle, size, gap, num_add, max_iter, dt0, dt_interval, rayleigh_para, num_ball, rad_min, rad_max, model_path, status)
     
-    args = (ncircle, size, gap, num_add, max_iter, dt0, dt_interval, rayleigh_para, num_ball, rad_min, rad_max, model_path, status)
-    
-    args
+    Parameters
     ----------
     ncircle : int
         单次向矩形区域内增加圆的数量
@@ -458,7 +445,7 @@ def create_model(*args):
 
     """
     
-    ncircle, size, gap, num_add, max_iter, dt0, dt_interval, rayleigh_para, num_ball, rad_min, rad_max, model_path, status = args
+    args = ncircle, size, gap, num_add, max_iter, dt0, dt_interval, rayleigh_para, num_ball, rad_min, rad_max, model_path, status
 
     # 生成需要填充的半径集合
     radius_sets = rayleigh_set(rayleigh_para, num_ball)
@@ -472,7 +459,7 @@ def create_model(*args):
 
     status['status'] = 'Running'
 
-    centers, radiuses = packing_hyperspheres_in_hypercube(ncircle, radius_sets, size, gap, num_add, max_iter, dt0, dt_interval, status)
+    centers, radiuses = packing_spheres_in_cube(ncircle, radius_sets, size, gap, num_add, max_iter, dt0, dt_interval, status)
 
     data = np.concatenate((centers, radiuses), axis=1)
 
